Struct Buffer

pub struct Buffer { /* private fields */ }
A handle to a VBO buffer in linear memory, to be used with Info. This handle is reference counted so can be cheaply cloned and used with mutliple Info instances without duplicating memory.

Implementations

Source

impl Buffer

pub fn new<T: Sized + Copy + 'static>(data: &[T]) -> Buffer

Allocate a new Buffer in Linear memory and copy data into it. Each element of data should correspond to data for a single vertex.

If you already have an owned [Vec] in Linear memory then Buffer::new_in_linear should be preferred to take ownership of that allocation instead of reallocating and copying.

pub fn new_with_stride(data: &[u8], stride: usize) -> Option<Buffer>

Allocate a new Buffer in Linear memory and copy data into it. The stride should correspond to the number of bytes in data per single vertex.

If you already have an owned [Vec] in Linear memory then Buffer::new_in_linear_with_stride should be preferred to take ownership of that allocation instead of reallocating and copying.

Errors
  • If the length of data is not a mutliple of stride
pub fn new_in_linear<B: BufferData>(data: B) -> Buffer

Convert an existing buffer allocated in Linear memory to a Buffer to be used with Info. Each element in data should correspond with data for a single vertex.

pub fn new_in_linear_with_stride( data: impl BufferData, stride: usize, ) -> Option<Buffer>

Convert an existing buffer of unstructured data allocated in Linear memory e.g. Vec<u8, LinearAllocator> to a Buffer to be used with Info. Each element in data should correspond with data for a single vertex.

Errors
  • If the length of data is not a mutliple of stride
pub fn as_ptr(&self) -> *const c_void

pub fn stride(&self) -> isize

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool