Struct Info

pub struct Info { /* private fields */ }
Vertex buffer info. This struct is used to describe the shape of the buffer data to be sent to the GPU for rendering.

Implementations

Source

impl Info

pub fn as_raw(&self) -> *mut C3D_BufInfo

pub fn new() -> Self

Construct buffer info without any registered data.

pub fn len(&self) -> u16

pub fn is_empty(&self) -> bool

pub fn add<'this, 'idx>( &'this mut self, vbo_buffer: Buffer, permutation: Permutation, ) -> Result<(), Error>
where 'this: 'idx,

Register vertex buffer object data with this Info. vbo_buffer is assumed to use one T per drawn primitive, and its layout is assumed to match the given permutation.

Errors

Registering VBO data may fail:

  • if vbo_data is (somehow) not allocated with the ctru::linear allocator
  • if the maximum number (12) of VBOs are already registered