pub struct Info { /* private fields */ }Expand description
Vertex buffer info. This struct is used to describe the shape of the buffer data to be sent to the GPU for rendering.
Implementations
Sourceimpl Info
impl Info
pub fn as_raw(&self) -> *mut C3D_BufInfo
pub fn len(&self) -> u16
pub fn is_empty(&self) -> bool
Sourcepub fn add<'this, 'idx>(
&'this mut self,
vbo_buffer: Buffer,
permutation: Permutation,
) -> Result<(), Error>where
'this: 'idx,
pub fn add<'this, 'idx>(
&'this mut self,
vbo_buffer: Buffer,
permutation: Permutation,
) -> Result<(), Error>where
'this: 'idx,
Register vertex buffer object data with this Info.
vbo_buffer is assumed to use one T per drawn primitive,
and its layout is assumed to match the given permutation.
Errors
Registering VBO data may fail:
- if
vbo_datais (somehow) not allocated with thectru::linearallocator - if the maximum number (12) of VBOs are already registered